==> Rapi-Blog-1.0000.tar.gz: Rapi-Blog-1.0000/share/templates/dashboard.md <==
## Quick Links 

<br>

<!--
<div class="metro">

  <div class="col-sm-6 col-md-3">
    <div class="thumbnail tile tile-medium tile-green">
       <a href="#" class="fa-links">
         <h1>RSS</h1>
         <i class="fa fa-3x fa-rss-square"></i>
      </a>
    </div>
  </div>
  
  <div class="col-sm-6 col-md-3">
    <div class="thumbnail tile tile-medium tile-green">
       <a href="#" class="fa-links">
         <h1>RSS</h1>
         <i class="fa fa-3x fa-rss-square"></i>
      </a>
    </div>
  </div>
  
</div>

<div style="clear:both;"></div>

-->

<div class="metro" style=max-width:800px;clear:both;">
  
  <div class="col-sm-6 col-md-3">
  
    <a 
      href="#![% c.mount_url %]/adm/main/db/db_post" 
      class="thumbnail tile tile-200 tile-red fa-links"
    >
       <h1>All Posts</h1>
       <i class="fa fa-5x fa-list"></i>
    </a>
  
    <a 
      href="#![% c.mount_url %]/adm/main/db/db_post?quick_search_cols=author&quick_search=[% User.username %]" 
      class="thumbnail tile tile-200 tile-purple fa-links"
    >
       <h1>My Posts</h1>
       <i class="fa fa-5x fa-list-ul"></i>
    </a>
 
    <a 
      href="#![% c.mount_url %]/adm/main/db/db_post/add" 
      class="thumbnail tile tile-200 tile-green fa-links"
    >
      <h1>New Post</h1>
      <i class="fa fa-5x fa-plus-square"></i>
    </a>

     <a 
       href="[% c.mount_url %]/" target="_blank"
       class="thumbnail tile tile-200 tile-orange fa-links"
     >
       <h1>Home page</h1>
       <i class="fa fa-5x fa-home"></i>
    </a>
    
    <a 
       href="#![% c.mount_url %]/adm/main/db/db_tag" 
       class="thumbnail tile tile-200 tile-blue fa-links"
     >
       <h1>Tags</h1>
       <i class="fa fa-5x fa-tags"></i>
    </a>

     <a 
       href="#![% c.mount_url %]/adm/main/db/db_user" 
       class="thumbnail tile tile-200 tile-pink fa-links"
     >
       <h1>Users</h1>
       <i class="fa fa-5x fa-users"></i>
    </a>
    
  </div>

</div>

==> Rapi-Blog-1.0003.tar.gz: Rapi-Blog-1.0003/share/templates/dashboard.md <==
## Quick Links 

<br>

<!--
<div class="metro">

  <div class="col-sm-6 col-md-3">
    <div class="thumbnail tile tile-medium tile-green">
       <a href="#" class="fa-links">
         <h1>RSS</h1>
         <i class="fa fa-3x fa-rss-square"></i>
      </a>
    </div>
  </div>
  
  <div class="col-sm-6 col-md-3">
    <div class="thumbnail tile tile-medium tile-green">
       <a href="#" class="fa-links">
         <h1>RSS</h1>
         <i class="fa fa-3x fa-rss-square"></i>
      </a>
    </div>
  </div>
  
</div>

<div style="clear:both;"></div>

-->

<div class="metro" style=max-width:800px;clear:both;">
  
  <div class="col-sm-6 col-md-3">
  
    <a 
      href="#!/adm/main/db/db_post" 
      class="thumbnail tile tile-200 tile-red fa-links"
    >
       <h1>All Posts</h1>
       <i class="fa fa-5x fa-list"></i>
    </a>
  
    <a 
      href="#!/adm/main/db/db_post?quick_search_cols=author&quick_search=[% User.username %]" 
      class="thumbnail tile tile-200 tile-purple fa-links"
    >
       <h1>My Posts</h1>
       <i class="fa fa-5x fa-list-ul"></i>
    </a>
 
    <a 
      href="#!/adm/main/db/db_post/add" 
      class="thumbnail tile tile-200 tile-green fa-links"
    >
      <h1>New Post</h1>
      <i class="fa fa-5x fa-plus-square"></i>
    </a>

     <a 
       href="[% c.mount_url %]/" target="_blank"
       class="thumbnail tile tile-200 tile-orange fa-links"
     >
       <h1>Home page</h1>
       <i class="fa fa-5x fa-home"></i>
    </a>
    
    <a 
       href="#!/adm/main/db/db_tag" 
       class="thumbnail tile tile-200 tile-blue fa-links"
     >
       <h1>Tags</h1>
       <i class="fa fa-5x fa-tags"></i>
    </a>

     <a 
       href="#!/adm/main/db/db_user" 
       class="thumbnail tile tile-200 tile-pink fa-links"
     >
       <h1>Users</h1>
       <i class="fa fa-5x fa-users"></i>
    </a>
    
  </div>

</div>
